@@ -1921,6 +1921,9 @@ def bsfcmap_dutycycle(df, speed_name, torque_name, bsfc_name, stepx, stepy, bubb
 
 
 
+df=pd.read_csv('C:/Users/lx379/Python_Tony/PDS_dm_lab/showcase_data/bsfctest.csv')
+bsfcmap_dutycycle(df, 'EngSpd', 'EngTrq', 'BSFC', 150, 150, 4000, 'XX', [180,200,220])
+
 
 
 
